# 20220601_dec3476_tuned

DL1ab for dec3476 with tuned configuration

lstchain config taken from 2022-05-23 prod


## command-line:
``` 
lstmcpipe_generate_config PathConfigAllSkyFullDL1ab --prod_id 20220601_dec3476_tuned --dec_list dec_3476 --kwargs source_prod_id=20220531_dec3476_std
```

